Crate cardinal_varvara

Crate cardinal_varvara 

The Varvara computer system

Re-exports

pub use controller::Key;

Modules

controller
Controller device and input handling for the Varvara system.
controller_gilrs
Gilrs controller device support for the Varvara system (enabled with the uses_gilrs feature).
controller_usb
USB controller device support for the Varvara system (enabled with the uses_usb feature).

Structs

Event
Internal events, accumulated by devices then applied to the CPU
EventData
Write to execute before calling the event vector
MouseState
Update to mouse state
Output
Output from Varvara::update, which may modify the GUI
RomData
Holds ROM data and optional symbol information for Uxn.
StreamData
Handle into an audio stream
TrackerState
Update to tracker state
Varvara
Handle to the Varvara system

Constants

AUDIO_CHANNELS
Expected number of audio channels

Functions

set_sample_rate
Sets the sample rate used by the audio engine (called by backend only)
spawn_console_worker
Spawns a worker thread that listens on stdin and emits characters