Controller

Struct Controller 

pub struct Controller {
    pub down: HashSet<Key>,
    pub buttons: u8,
}
Main controller device for the Varvara system.

Fields

down: HashSet<Key>

Keys that are currently held down

buttons: u8

Current button state

Implementations

Source

impl Controller

pub fn new() -> Self

Builds a new controller with no keys held

pub fn char(&mut self, vm: &mut Uxn<'_>, c: u8) -> Event

Sends a single character event

pub fn pressed( &mut self, vm: &mut Uxn<'_>, k: Key, repeat: bool, ) -> Option<Event>

Send the given key event, returning an event if needed

pub fn released(&mut self, vm: &mut Uxn<'_>, k: Key) -> Option<Event>

Indicate that the given key has been released

This may change our button state and return an event

pub fn check_buttons(&mut self, vm: &mut Uxn<'_>, repeat: bool) -> Option<Event>

Checks the current button states and returns an event if any button state changed.