The Varvara computer system
Re-exports
pub use controller::Key;
Modules
- controller
- Controller device and input handling for the Varvara system.
- controller_
gilrs - Gilrs controller device support for the Varvara system (enabled with the
uses_gilrsfeature). - controller_
usb - USB controller device support for the Varvara system (enabled with the
uses_usbfeature).
Structs
- Event
- Internal events, accumulated by devices then applied to the CPU
- Event
Data - Write to execute before calling the event vector
- Mouse
State - Update to mouse state
- Output
- Output from Varvara::update, which may modify the GUI
- RomData
- Holds ROM data and optional symbol information for Uxn.
- Stream
Data - Handle into an audio stream
- Tracker
State - Update to tracker state
- Varvara
- Handle to the Varvara system
Constants
- AUDIO_
CHANNELS - Expected number of audio channels
Functions
- set_
sample_ rate - Sets the sample rate used by the audio engine (called by backend only)
- spawn_
console_ worker - Spawns a worker thread that listens on
stdinand emits characters