pub struct Controller {
pub down: HashSet<Key>,
pub buttons: u8,
}Expand description
Main controller device for the Varvara system.
Fields
down: HashSet<Key>Keys that are currently held down
Current button state
Implementations
Sourceimpl Controller
impl Controller
Sourcepub fn pressed(
&mut self,
vm: &mut Uxn<'_>,
k: Key,
repeat: bool,
) -> Option<Event>
pub fn pressed( &mut self, vm: &mut Uxn<'_>, k: Key, repeat: bool, ) -> Option<Event>
Send the given key event, returning an event if needed
Sourcepub fn released(&mut self, vm: &mut Uxn<'_>, k: Key) -> Option<Event>
pub fn released(&mut self, vm: &mut Uxn<'_>, k: Key) -> Option<Event>
Indicate that the given key has been released
This may change our button state and return an event
Checks the current button states and returns an event if any button state changed.